@@ -40,8 +40,10 @@ ctrl <- control_parsnip(verbosity = 0, catch = FALSE)
 test_that('model fitting', {
   skip_on_cran()
   skip_if_not_installed("keras")
+  skip_if(is.null(tensorflow::tf_version()))
+
+  set_tf_seed(257)
 
-  set.seed(257)
   expect_error(
     fit1 <-
       fit_xy(
@@ -53,7 +55,8 @@ test_that('model fitting', {
     regexp = NA
   )
 
-  set.seed(257)
+  set_tf_seed(257)
+
   expect_error(
     fit2 <-
       fit_xy(
@@ -107,6 +110,7 @@ test_that('model fitting', {
 test_that('classification prediction', {
   skip_on_cran()
   skip_if_not_installed("keras")
+  skip_if(is.null(tensorflow::tf_version()))
 
   library(keras)
 
@@ -151,10 +155,12 @@ test_that('classification prediction', {
 test_that('classification probabilities', {
   skip_on_cran()
   skip_if_not_installed("keras")
+  skip_if(is.null(tensorflow::tf_version()))
 
   library(keras)
 
-  set.seed(257)
+  set_tf_seed(257)
+
   lr_fit <-
     fit_xy(
       basic_mod,
@@ -163,14 +169,15 @@ test_that('classification probabilities', {
       y = tr_dat$Class
     )
 
-  keras_pred <- keras::predict_proba(lr_fit$fit, as.matrix(te_dat[, -1]))
+  keras_pred <- predict(lr_fit$fit, as.matrix(te_dat[, -1]))
   colnames(keras_pred) <- paste0(".pred_", lr_fit$lvl)
   keras_pred <- as_tibble(keras_pred)
 
   parsnip_pred <- predict(lr_fit, te_dat[, -1], type = "prob")
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
 
-  set.seed(257)
+  set_tf_seed(257)
+
   plrfit <-
     fit_xy(
       reg_mod,
@@ -179,7 +186,7 @@ test_that('classification probabilities', {
       y = tr_dat$Class
     )
 
-  keras_pred <- keras::predict_proba(plrfit$fit, as.matrix(te_dat[, -1]))
+  keras_pred <- predict(plrfit$fit, as.matrix(te_dat[, -1]))
   colnames(keras_pred) <- paste0(".pred_", lr_fit$lvl)
   keras_pred <- as_tibble(keras_pred)
 
@@ -187,5 +194,3 @@ test_that('classification probabilities', {
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
 
 })
-
-
